<?php

namespace Drupal\page_notifications\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Component\Render\FormattableMarkup;
use Drupal\page_notifications\Form\AccessVerificationStep;

class AdminSubscriptionsListPage extends ControllerBase {

  /**
   * {@inheritdoc}
   */
  protected function getModuleName() {
    return 'admin-node-subscribers-list';
  }

  public function getNodeSubscribersList($row_node_id = NULL) {

    if ($row_node_id && !is_null($row_node_id)) {
      $query = \Drupal::entityQuery('node')
        ->condition('type', 'page_notify_subscriptions')
        ->condition('field_page_notify_node_id', $row_node_id, '=')
        ->condition('status', 1)
        ->sort('created', 'DESC')
        ->pager(25);
      $records = $query->execute();
    } else {
      $query = \Drupal::entityQuery('node')
        ->condition('type', 'page_notify_subscriptions')
        ->condition('status', 1)
        ->sort('created', 'DESC')
        ->pager(25);
      $records = $query->execute();
    }

      $header = array(
        array('data' => $this->t('Node Title'), 'field' => 'title', 'sort' => 'asc'),
        array('data' => $this->t('E-Mail'), 'field' => 'e-mail'),
        array('data' => $this->t('Operations')),
      );

      $rows = array();
      foreach ($records as $record) {
        $node_record = \Drupal\node\Entity\Node::load($record);
        $field_token_notify = $node_record->get("field_page_notify_token")->getValue();
        $field_node_id_notify = $node_record->get("field_page_notify_node_id")->getValue();
        $field_page_notify_email = $node_record->get("field_page_notify_email")->getValue();

        $subscriptions_record = \Drupal\node\Entity\Node::load($field_node_id_notify[0]['value']);
          $rows[] = array('data' => array(
            'title' => new FormattableMarkup('<a href="@page_url">@page_title</a>',
              [
                '@page_title' => $subscriptions_record->getTitle(),
                '@page_url' => $subscriptions_record->toUrl()->toString(),
              ]),
            'e-mail' => new FormattableMarkup('@user_email',
                [
                  '@user_email' => $field_page_notify_email[0]['value'],
                ]),
            'cancel_one' => new FormattableMarkup('<a href="@record_link">@name</a>',
                ['@name' => 'View', '@record_link' => $node_record->toUrl()->toString()]
              ),
          ));
      }
      $page_name = '<h1>Subscriptions List</h1>';
      $build['page_name'] = [
        '#markup' => $page_name,
        '#attributes' => [
          'class' => ['page-notifications-user-list-page-name'],
        ],
      ];
      $build['config_table'] = array(
        '#theme' => 'table',
        '#header' => $header,
        '#rows' => $rows,
        '#empty' => t('No records found'),
        '#attributes' => [
          'class' => ['page-notifications-block-subscriberpage'],
          'id' => 'page-notifications-block-subscriberpage',
          'no_striping' => TRUE,
        ],
      );
      $build['pager'] = array(
        '#type' => 'pager'
      );
      return $build;
  }
}
